Your first plugin
=================

.. todo::

    Work in progress! Extensive developer documentation will soon be available. Meanwhile, we invite you to explore the `GitHub repositories <https://github.com/timeflux>`_ and learn by example.

Setting a developement environment
----------------------------------

- Go to the `timeflux_example <https://github.com/timeflux/timeflux_example>`_ repository and click the button: `Use this template` to create a new repository from this plugin.
- Clone your new repository, modify `setup.cfg` and rename the subfolder called `timeflux_example`.
- Install the new plugin with: ``pip install -e ".[dev]"``
- Work your magic.
